<?php
/**
 * PEAR_Installer_Role_Glplugin
 *
 * PHP versions 4 and 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @package    Geeklogplugins
 * @author     Tias Guns <tias@php.net>
 * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
 */

/**
 * @package    Geeklogplugins
 * @author     Tias Guns <tias@php.net>
 * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
 * @version    Release: @package_version@
 */
class PEAR_Installer_Role_Glpluginadmin extends PEAR_Installer_Role_Common
{
    /**
     * This is called for each file to set up the directories and files
     * @param PEAR_PackageFile_v1|PEAR_PackageFile_v2
     * @param array attributes from the <file> tag
     * @param string file name
     * @return array an array consisting of:
     *
     *    1 the original, pre-baseinstalldir installation directory
     *    2 the final installation directory
     *    3 the full path to the final location of the file
     *    4 the location of the pre-installation file
     *
     * Custom paths for Geeklog plugins !
     */
    function processInstallation($pkg, $atts, $file, $tmp_path, $layer = null)
    {
        // This role installs the plugin files in PATH_HTML/admin/plugins/<plugin>
        // It ignores baseinstalldir from package.xml and creates the destination dir
        // using the configuration var 'geeklog_path' and the plugin name.
        $plugin_name = str_replace('geeklog_plugin_', '', strtolower($pkg->getPackage()));

        $roleInfo = PEAR_Installer_Role_Common::getInfo('PEAR_Installer_Role_' . 
            ucfirst(str_replace('pear_installer_role_', '', strtolower(get_class($this)))));
        if (PEAR::isError($roleInfo)) {
            return $roleInfo;
        }
        if (!$roleInfo['locationconfig']) {
            return false;
        }

        // get geeklog path, or use default
        $geeklog_path = $this->config->get($roleInfo['locationconfig'], $layer, $pkg->getChannel());
        if ($geeklog_path == '') {
            // fall back to Role_Web and baseinstalldir
            $geeklog_path = $this->config->get('role_web');
            if (!empty($atts['baseinstalldir'])) {
                $geeklog_path .= DIRECTORY_SEPARATOR . $atts['baseinstalldir'];
            }
            $geeklog_path .= DIRECTORY_SEPARATOR.'public_html';
        }

        // save_destdir = PATH_HTML/admin/plugins/
        $save_destdir = $geeklog_path.DIRECTORY_SEPARATOR.'admin'.DIRECTORY_SEPARATOR.'plugins';
        // dest_dir = PATH_HTML/admin/plugins/<plugin>
        $dest_dir = $save_destdir.DIRECTORY_SEPARATOR.$plugin_name;

        $orig_file = $tmp_path . DIRECTORY_SEPARATOR . $file;
        // append relative path
        // first strip admin/...
        if (substr($file, 0, strlen('admin/')) == 'admin/') {
            $file_ = $file; // Tias
            $file = substr($file, strlen('admin/'));
        }
        if (dirname($file) != '.' && empty($atts['install-as'])) {
            $dest_dir .= DIRECTORY_SEPARATOR . dirname($file);
        }
        // dest_file = dest_dir . file [or install-as]
        if (empty($atts['install-as'])) {
            $dest_file = $dest_dir . DIRECTORY_SEPARATOR . basename($file);
        } else {
            $dest_file = $dest_dir . DIRECTORY_SEPARATOR . $atts['install-as'];
        }

        // Clean up the DIRECTORY_SEPARATOR mess
        $ds2 = DIRECTORY_SEPARATOR . DIRECTORY_SEPARATOR;
        
        list($dest_dir, $dest_file, $orig_file) = preg_replace(array('!\\\\+!', '!/!', "!$ds2+!"),
                                                    array(DIRECTORY_SEPARATOR, DIRECTORY_SEPARATOR,
                                                          DIRECTORY_SEPARATOR),
                                                    array($dest_dir, $dest_file, $orig_file));
        return array($save_destdir, $dest_dir, $dest_file, $orig_file);
    }
}
?>
